[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677
mjs
mjs at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:52:34 UTC 2009
The following commit has been merged in the debian/unstable branch:
commit ca63fa20c6905b35767358ad9fdb3fb5f1e4899f
Author: mjs <mjs at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date: Wed Aug 20 22:05:58 2003 +0000
Reviewed by Richard.
- fixed 3384963 - REGRESSION: assertion in copyPathRemovingDots, crash parsing URL in snippet editor
* kwq/KWQKURL.mm:
(copyPathRemovingDots): It's OK if the path is entirely empty.
git-svn-id: http://svn.webkit.org/repository/webkit/trunk@4851 268f45cc-cd09-0410-ab3c-d52691b4dbfc
diff --git a/WebCore/ChangeLog-2003-10-25 b/WebCore/ChangeLog-2003-10-25
index 60b8fed..bb2cdf8 100644
--- a/WebCore/ChangeLog-2003-10-25
+++ b/WebCore/ChangeLog-2003-10-25
@@ -1,3 +1,12 @@
+2003-08-20 Maciej Stachowiak <mjs at apple.com>
+
+ Reviewed by Richard.
+
+ - fixed 3384963 - REGRESSION: assertion in copyPathRemovingDots, crash parsing URL in snippet editor
+
+ * kwq/KWQKURL.mm:
+ (copyPathRemovingDots): It's OK if the path is entirely empty.
+
2003-08-20 David Hyatt <hyatt at apple.com>
Fix for 3385211, <td>s should ignore the float property in quirks mode. This
diff --git a/WebCore/ChangeLog-2005-08-23 b/WebCore/ChangeLog-2005-08-23
index 60b8fed..bb2cdf8 100644
--- a/WebCore/ChangeLog-2005-08-23
+++ b/WebCore/ChangeLog-2005-08-23
@@ -1,3 +1,12 @@
+2003-08-20 Maciej Stachowiak <mjs at apple.com>
+
+ Reviewed by Richard.
+
+ - fixed 3384963 - REGRESSION: assertion in copyPathRemovingDots, crash parsing URL in snippet editor
+
+ * kwq/KWQKURL.mm:
+ (copyPathRemovingDots): It's OK if the path is entirely empty.
+
2003-08-20 David Hyatt <hyatt at apple.com>
Fix for 3385211, <td>s should ignore the float property in quirks mode. This
diff --git a/WebCore/kwq/KWQKURL.mm b/WebCore/kwq/KWQKURL.mm
index b249b77..045c166 100644
--- a/WebCore/kwq/KWQKURL.mm
+++ b/WebCore/kwq/KWQKURL.mm
@@ -861,9 +861,10 @@ static int copyPathRemovingDots(char *dst, const char *src, int srcStart, int sr
char *bufferPathStart = dst;
const char *baseStringPos = baseStringStart;
- // this code is unprepared for paths that do not begin with a slash
- // and we should always have one in the source string
- ASSERT(baseStringPos[0] == '/');
+ // this code is unprepared for paths that do not begin with a
+ // slash and we should always have one in the source string (but a
+ // totally empty path is OK and does not need to start with a slash)
+ ASSERT(srcStart == srcEnd || baseStringPos[0] == '/');
// copy the leading slash into the destination
*dst = *baseStringPos;
--
WebKit Debian packaging
More information about the Pkg-webkit-commits
mailing list